extensions [palette]

turtles-own ;; representing the characteristics of the citizens
[
  ;; true/false for eID possesion
  has_eID
  ;; 3 Helper variables: Just for the setting the attitude at the beginning if uniform distribution is chosen
  neutral_attitude_eID
  positive_attitude_eID
  negative_attitude_eID
  ;; baseline attitude score set to a value between 0 and 100 later
  baseline_attitude_eID
  ;; value that is added to baseline attitude
  temp_attitude_change
  ;; total attitude
  attitude_eID
  ;; ticks (weeks) until new id is necessary
  ticks_until_new_id
]

globals
[
  %percentage_eID ;; percentage of citizens that posseses eID
  %threshold_get_eID ;; threshold for attitude for getting eID

  ;; Variables used for the initial setting of the distribution of attitutes by inputs
  %attitude_mean
  %attitude_variance
  ;; Second gaussian
  %attitude_b_mean
  %attitude_b_variance
  ;; percentages set by inputs
  %neutral_opinion
  %ratio_positive_negative_opinion
  ;; limits for region of positive and negative opinion
  lower_limit_positive
  upper_limit_positive
  lower_limit_negative
  upper_limit_negative

  ;; variable for tracking mean attitude of citizens
  mean_baseline_attitude_citizens
  ;; temporary attitude change given by input
  old_temp_value
  ;; temporary effect on attitude
  mean_temporary_attitude_effect
  ;; variable for tracking mean attitude of citizens
  mean_attitude_citizens
]

to setup-uni-distribution-attitude ;; function for setting initial distribution if uniform is chosen
  ask turtles [
    ;; Helper variables
    set neutral_attitude_eID false
    set positive_attitude_eID false
    set negative_attitude_eID false
    ;; Set baseline attitude
    set baseline_attitude_eID 50
  ]
  ;; Set opinion percentages from inputs
  set %neutral_opinion unknown_neutral
  set %ratio_positive_negative_opinion ratio_positive_negative
  ;; Set limits for region of positive and negative opinion
  set lower_limit_positive 50
  set upper_limit_positive 100
  set lower_limit_negative 0
  set upper_limit_negative 50
  ;; Set attitudes
  ask n-of (count turtles * (%neutral_opinion / 100) ) turtles [
    set neutral_attitude_eID true
  ]
  ask n-of ((count turtles with [neutral_attitude_eID = false]) * (%ratio_positive_negative_opinion / 100) ) turtles with [neutral_attitude_eID = false] [
    set positive_attitude_eID true
  ]
  ask turtles with [neutral_attitude_eID = false and positive_attitude_eID = false] [
    set negative_attitude_eID true
  ]
  ;; Set score for opinion towards eID
  ask turtles with [neutral_attitude_eID = true] [
    set baseline_attitude_eID random-normal 50 10
  ]
  ask turtles with [negative_attitude_eID = true] [
    set baseline_attitude_eID ((random-float (upper_limit_negative - lower_limit_negative)) + lower_limit_negative)
  ]
  ask turtles with [positive_attitude_eID = true] [
    set baseline_attitude_eID ((random-float (upper_limit_positive - lower_limit_positive)) + lower_limit_positive)
  ]
end

to setup-normal-distribution-attitude ;; function for setting initial distribution if one normal is chosen
  ;; Set variables for distribution
  set %attitude_mean a_mean
  set %attitude_variance a_variance
  ;; Sampling from normal distribution with limits 0 and 100 for attitude values
  ask turtles [
    let temp_attitude -1
    while [ (temp_attitude < 0) or (temp_attitude > 100) ] [
      set temp_attitude random-normal %attitude_mean %attitude_variance
    ]
    set baseline_attitude_eID temp_attitude
  ]
end

to setup-2-normal-distribution-attitude ;; function for setting initial distribution if two normal is chosen
  ;; Set variables for distribution
  set %attitude_mean a_mean
  set %attitude_variance a_variance
  set %attitude_b_mean b_mean
  set %attitude_b_variance b_variance
  ask turtles [
    set baseline_attitude_eID -1
  ]
  ;; Sampling from normal distribution with limits 0 and 100 for attitude values for two halves of all citizens
  ask n-of ((count turtles) / 2) turtles [
    let temp_attitude -1
    while [ (temp_attitude < 0) or (temp_attitude > 100) ] [
      set temp_attitude (random-normal %attitude_mean %attitude_variance)
    ]
    set baseline_attitude_eID temp_attitude
  ]
  ask turtles with [ baseline_attitude_eID = -1 ] [
    let temp_attitude -1
    while [ (temp_attitude < 0) or (temp_attitude > 100) ] [
      set temp_attitude (random-normal %attitude_b_mean %attitude_b_variance)
    ]
    set baseline_attitude_eID temp_attitude
  ]
end

to set-temporary-attitude-change
  ifelse amount_change_attitude = 0 [
    ask turtles [
      set temp_attitude_change 0
      set attitude_eID (baseline_attitude_eID + temp_attitude_change)
    ]
    set old_temp_value 0
  ] [
    if amount_change_attitude != old_temp_value [
      set old_temp_value amount_change_attitude
      ask turtles [
        let sample random-normal old_temp_value 5

        ifelse (((sample + baseline_attitude_eID) <= 100) and ((sample + baseline_attitude_eID) >= 0)) [
          set temp_attitude_change sample
          set attitude_eID (baseline_attitude_eID + temp_attitude_change)
        ] [
          if sample + baseline_attitude_eID > 100 [
            set temp_attitude_change (100 - baseline_attitude_eID)
            set attitude_eID (baseline_attitude_eID + temp_attitude_change)
          ]
          if sample + baseline_attitude_eID < 0 [
            set temp_attitude_change (0 - baseline_attitude_eID)
            set attitude_eID (baseline_attitude_eID + temp_attitude_change)
          ]
        ]
      ]
    ]
  ]
end

to set-temporary-attitude-change-alternative
  ifelse amount_change_attitude = 0 [
    ask turtles [
      set temp_attitude_change 0
      set attitude_eID (baseline_attitude_eID + temp_attitude_change)
    ]
    set old_temp_value 0
  ] [
    if amount_change_attitude != old_temp_value [
      set old_temp_value amount_change_attitude
      ask turtles [

        let distmax (100 - baseline_attitude_eID)
        let distmin (baseline_attitude_eID - 0)

        let sample old_temp_value;;random-normal old_temp_value 5

        ifelse ( sample < 0 ) [
          set sample max (list sample (0 - distmin / 2))
        ][
          set sample min (list sample (distmax / 2))
        ]

        set temp_attitude_change sample
        set attitude_eID (baseline_attitude_eID + temp_attitude_change)
      ]
    ]
  ]
end

to set-temporary-attitude-change-alternative-2
  ifelse amount_change_attitude = 0 [
    ask turtles [
      set temp_attitude_change 0
      set attitude_eID (baseline_attitude_eID + temp_attitude_change)
    ]
    set old_temp_value 0
  ] [
    if amount_change_attitude != old_temp_value [
      set old_temp_value amount_change_attitude
      ask turtles [
        set temp_attitude_change (amount_change_attitude - ( abs (baseline_attitude_eID - 50) ) / ( 50  / amount_change_attitude ))
        set attitude_eID (baseline_attitude_eID + temp_attitude_change)
      ]
    ]
  ]
end


to setup ;; inital setup
  clear-all
  create-turtles citizens
  [setxy random-xcor random-ycor ;;
    set size 1
    set has_eID false
    set ticks_until_new_id 1
    set old_temp_value 0
  ]

  ;; Set global variables for eID possesion percentage and threshold
  set %percentage_eID start_percentage_eID
  set %threshold_get_eID start_threshold_get_eID

  ;; Setup attitutde distribution by calling other function
  (ifelse
    opinion_distribution = "uniform" [
      setup-uni-distribution-attitude
    ]
    opinion_distribution = "normal" [
      setup-normal-distribution-attitude
    ]
    opinion_distribution = "2_normal" [
      setup-2-normal-distribution-attitude
    ]
  )
  ;; Set global variable for baseline attitude
  set mean_baseline_attitude_citizens (mean [baseline_attitude_eID] of turtles)
  ;; Consider temporary effects on attitude
  set-temporary-attitude-change-alternative
  ;; Set mean for temporariy effect
  set mean_temporary_attitude_effect mean [temp_attitude_change] of turtles
  ;; Set global variable for mean attitude
  set mean_attitude_citizens (mean [attitude_eID] of turtles)

  ;; Set turtle shape and color
  ask turtles [
    set shape "person"
    ;;set color yellow
    ;;set color scale-color green attitude_eID 0 100
    set color palette:scale-gradient [[130 22 10] [13 158 51]] attitude_eID 0 100
  ]
  ;; set eID possesion
  ask n-of (count turtles * (%percentage_eID / 100)) turtles [
    set has_eID true
  ]
  ;; Set maximum timespan until id renewal
  ;; For those who start with the old id
  ask n-of (count turtles * ((max_timespan_before_new_id + start_percentage_eID) / 100 )) turtles [
    set ticks_until_new_id 520
  ]
  ;; Everyone else uniformly distributed over the next 10 years
  ask turtles with [ticks_until_new_id < 520] [
    set ticks_until_new_id ((random 519) + 1)
  ]

  Reset-ticks
end

to update-global-variables
  set %percentage_eID (count turtles with [ has_eID ] / count turtles) * 100
  set mean_attitude_citizens (mean [attitude_eID] of turtles)
  set mean_baseline_attitude_citizens (mean [baseline_attitude_eID] of turtles)
  set mean_temporary_attitude_effect mean [temp_attitude_change] of turtles
end

to update-setup
  set %threshold_get_eID start_threshold_get_eID
end

to go-year
  repeat 52 [
    go
  ]
end

to go-x-weeks
  repeat stepsize_go [
    go
  ]
end

to go ;; Timestep = 1 week
  ;; Update some setup variables
  update-setup
  ;; Update temporary attitude change
  set-temporary-attitude-change-alternative
  ;; Citizens that need a new id
  ask turtles with [ ticks_until_new_id = 0 ] [
    ;; If opinion is positive enough get an eID and set time until new id to 10 years
    ifelse attitude_eID >= %threshold_get_eID [
        set has_eID true
        set ticks_until_new_id 520
      ] [
        set has_eID false
        set ticks_until_new_id 520
    ]
  ]
  ;; Needing a new id moves on week closer
  ask turtles [
    set ticks_until_new_id (ticks_until_new_id - 1)
  ]
  ;; Updating variables
  update-global-variables
  tick
end
@#$#@#$#@
GRAPHICS-WINDOW
210
10
647
448
-1
-1
13.0
1
10
1
1
1
0
1
1
1
-16
16
-16
16
0
0
1
ticks
30.0

BUTTON
21
26
85
59
Setup
setup\n
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
22
170
194
203
citizens
citizens
5
1000
1000.0
1
1
NIL
HORIZONTAL

SLIDER
16
691
204
724
start_percentage_eID
start_percentage_eID
0
50
0.0
0.1
1
%
HORIZONTAL

PLOT
680
17
1158
444
Entwicklung eID
NIL
NIL
0.0
600.0
0.0
100.0
true
true
"" ""
PENS
"% has eID" 1.0 0 -13840069 true "" "plot %percentage_eID"

BUTTON
85
26
186
59
Go forever
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
680
457
1159
607
Histogram Attitude
NIL
NIL
0.0
101.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "histogram [attitude_eID] of turtles"

TEXTBOX
23
292
199
353
Falls Gleichverteilung: Unbekannt & Verhältnis positiv zu negativ (Zuweisung Zahlenwerte über Intervalle)
11
0.0
1

SLIDER
117
468
209
501
a_variance
a_variance
0
30
17.5
0.1
1
NIL
HORIZONTAL

TEXTBOX
24
749
174
791
eID Grenze (Einstellung größer gleich), änderbar zwischen Ticks
11
0.0
1

SLIDER
14
797
201
830
start_threshold_get_eID
start_threshold_get_eID
0
100
100.0
1
1
NIL
HORIZONTAL

TEXTBOX
215
465
594
1105
1. Stufe:\nEigenschaften Bürger:innen:\neID: ja / nein\nGrundeinstellung: 0 bis 100\nZeit bis zum nächsten ID: 0 bis 520 Wochen\n\n3 Einstellungesmöglichkeit für Einstellung:\n1. Stückweise (positiv, negativ) gleichverteilt\n2. Sampling von einer Normalverteilung\n3. Sampling von 2 Normalverteilung\n\nVerteilung visualisiert in der Farbe der Personen und einem Histogram.\n\nEs gibt einen \"globalen\" Threshold zu Grundeinstellung, ab wann sich Bürger:innen eine eID holen. Dieser ist zwischen Ticks anpassbar. Abhängig von Einstellung, Threshold und Zeitpunkt holen sich einzelne Bürger:innen einen eID.\n\nZeit:\n1 Tick = 1 Woche\n1 Jahr = 52 Ticks
13
0.0
1

SLIDER
21
354
193
387
unknown_neutral
unknown_neutral
0
100
6.2
0.1
1
%
HORIZONTAL

SLIDER
21
393
195
426
ratio_positive_negative
ratio_positive_negative
0
100
87.4
0.1
1
%
HORIZONTAL

TEXTBOX
19
573
198
614
Anteil derer, die sich vor Einführung des neuen absichtlich den alten Perso holen
11
0.0
1

SLIDER
16
622
199
655
max_timespan_before_new_id
max_timespan_before_new_id
0
50
33.2
0.1
1
%
HORIZONTAL

TEXTBOX
17
663
194
691
Anteil derer, die den eID direkt am Anfang haben
11
0.0
1

PLOT
1172
455
1526
607
Weeks until new ID
NIL
NIL
1.0
521.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "histogram [ticks_until_new_id] of turtles"

SLIDER
22
468
114
501
a_mean
a_mean
0
100
50.6
0.1
1
NIL
HORIZONTAL

CHOOSER
22
235
160
280
opinion_distribution
opinion_distribution
"uniform" "normal" "2_normal"
1

TEXTBOX
24
204
194
232
Grundeinstellung: Wahl der Verteilung
11
0.0
1

TEXTBOX
23
435
197
477
Falls Normalverteilung: Sampling mit Bedingung 0 bis 100.
11
0.0
1

SLIDER
20
538
112
571
b_mean
b_mean
0
100
79.2
0.1
1
NIL
HORIZONTAL

SLIDER
115
538
207
571
b_variance
b_variance
0
30
9.7
0.1
1
NIL
HORIZONTAL

TEXTBOX
26
502
204
530
2te Normalverteilung für Polarisierung
11
0.0
1

BUTTON
21
60
98
93
Go Year
go-year
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
99
60
207
93
Go x Weeks
go-x-weeks
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
31
95
205
128
stepsize_go
stepsize_go
1
52
8.0
1
1
weeks
HORIZONTAL

MONITOR
1170
26
1242
71
% has eID
%percentage_eID
1
1
11

MONITOR
1171
178
1306
223
mean attitude
mean_attitude_citizens
1
1
11

SLIDER
17
886
212
919
amount_change_attitude
amount_change_attitude
-20
20
0.0
1
1
NIL
HORIZONTAL

MONITOR
1170
83
1305
128
mean baseline attitude
mean_baseline_attitude_citizens
1
1
11

MONITOR
1171
131
1306
176
mean temporary effect attitude
mean_temporary_attitude_effect
1
1
11

TEXTBOX
19
849
230
886
Temporären Effekt auf Einstellung (wirkt falls != 0)
13
0.0
1

@#$#@#$#@
## WHAT IS IT?

(a general understanding of what the model is trying to show or explain)

## HOW IT WORKS

(what rules the agents use to create the overall behavior of the model)

## HOW TO USE IT

(how to use the model, including a description of each of the items in the Interface tab)

## THINGS TO NOTICE

(suggested things for the user to notice while running the model)

## THINGS TO TRY

(suggested things for the user to try to do (move sliders, switches, etc.) with the model)

## EXTENDING THE MODEL

(suggested things to add or change in the Code tab to make the model more complicated, detailed, accurate, etc.)

## NETLOGO FEATURES

(interesting or unusual features of NetLogo that the model uses, particularly in the Code tab; or where workarounds were needed for missing features)

## RELATED MODELS

(models in the NetLogo Models Library and elsewhere which are of related interest)

## CREDITS AND REFERENCES

(a reference to the model's URL on the web if it has one, as well as any other necessary credits, citations, and links)
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270
@#$#@#$#@
NetLogo 6.4.0
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180
@#$#@#$#@
0
@#$#@#$#@
