from mesa import Agent, Model
from mesa.time import RandomActivation
import numpy as np
import matplotlib.pyplot as plt

# Bürger-Agent
class CitizenAgent(Agent):
    def __init__(self, unique_id, model):
        super().__init__(unique_id, model)
        self.attitude = np.random.normal(model.mean_attitude, model.stddev_attitude)
        self.attitude = int(np.clip(np.round(self.attitude), 0, 100))

# Simulations-Modell
class AttitudeModel(Model):
    def __init__(self, num_citizens, mean_attitude, stddev_attitude):
        self.num_citizens = num_citizens
        self.mean_attitude = mean_attitude
        self.stddev_attitude = stddev_attitude
        self.schedule = RandomActivation(self)
        self.datacollector = self.datacollector_description()
        for i in range(self.num_citizens):
            citizen = CitizenAgent(i, self)
            self.schedule.add(citizen)

    def datacollector_description(self):
        return {
            "Attitudes": lambda model: [agent.attitude for agent in model.schedule.agents]
        }

    def step(self):
        self.schedule.step()
        self.datacollector.collect(self)

# Simulationsparameter
num_citizens = 1000
mean_attitude = 50
stddev_attitude = 20
num_iterations = 1

# Simulation ausführen
model = AttitudeModel(num_citizens, mean_attitude, stddev_attitude)
for _ in range(num_iterations):
    model.step()

# Ergebnisse visualisieren
attitudes = model.datacollector.get_model_vars_dataframe()["Attitudes"].iloc[-1]
plt.figure(figsize=(8, 6))
plt.hist(attitudes, bins=20, edgecolor='black', density=True)
plt.title("Verteilung der Einstellungen gegenüber dem Dienst")
plt.xlabel("Einstellung (0-100)")
plt.ylabel("Dichte")
plt.show()
