import random

class Turtle:
    def __init__(self, x, y):
        self.x = x
        self.y = y
        self.user = False
        self.color = "blue" if not self.user else "green"

    def evaluate_adoption(self, turtles, adoption_prob):
        if not self.user:
            user_neighbors = sum(1 for turtle in turtles if turtle.user and abs(turtle.x - self.x) <= 1 and abs(turtle.y - self.y) <= 1)
            if user_neighbors > 0 and random.random() < adoption_prob:
                self.become_user()

    def become_user(self):
        self.user = True
        self.color = "green"

    def move(self, max_x, max_y):
        self.x += random.choice([-1, 0, 1])
        self.y += random.choice([-1, 0, 1])
        self.x = max(0, min(self.x, max_x))
        self.y = max(0, min(self.y, max_y))

class Simulation:
    def __init__(self, num_turtles, initial_users, adoption_prob, world_size):
        self.turtles = [Turtle(random.randint(0, world_size[0]), random.randint(0, world_size[1])) for _ in range(num_turtles)]
        for turtle in random.sample(self.turtles, initial_users):
            turtle.become_user()
        self.adoption_prob = adoption_prob
        self.world_size = world_size

    def step(self):
        for turtle in self.turtles:
            turtle.evaluate_adoption(self.turtles, self.adoption_prob)
            turtle.move(self.world_size[0], self.world_size[1])

    def run(self, steps):
        for _ in range(steps):
            self.step()
            self.display()

    def display(self):
        for y in range(self.world_size[1] + 1):
            for x in range(self.world_size[0] + 1):
                turtle_at_position = next((turtle for turtle in self.turtles if turtle.x == x and turtle.y == y), None)
                if turtle_at_position:
                    print("G" if turtle_at_position.user else "B", end=" ")
                else:
                    print(".", end=" ")
            print()
        print()

# Parameter festlegen
num_turtles = 100
initial_users = 10
adoption_prob = 0.3
world_size = (20, 20)
simulation_steps = 20

# Simulation ausführen
simulation = Simulation(num_turtles, initial_users, adoption_prob, world_size)
simulation.run(simulation_steps)
