import numpy as np
import random

def initialize_agents(N, p_initial):
  """Initialisiert eine Population von Agenten."""
  state = np.zeros(N)
  for i in range(N):
    if random.random() < p_initial:
      state[i] = 1
  return state

def select_neighbors(N, k):  # k wird hier definiert
  """Wählt zufällige Nachbarn für jeden Agenten aus."""
  neighbors = np.zeros((N, k))
  for i in range(N):
    neighbors[i] = np.random.choice(N, size=k, replace=False)
  return neighbors

def update_agents(state, neighbors, p_adopt):
  """Aktualisiert den Zustand der Agenten basierend auf sozialer Beeinflussung."""
  new_state = state.copy()
  for i in range(N):
    majority_adopted = np.mean(state[neighbors[i]]) >= 0.5
    if state[i] == 0 and majority_adopted:
      if random.random() < p_adopt:
        new_state[i] = 1
  return new_state

def simulate(N, p_initial, p_adopt, T, k):  # k wird als Argument übergeben
  """Führt die Simulation durch."""
  state = initialize_agents(N, p_initial)
  for t in range(T):
    neighbors = select_neighbors(N, k)
    state = update_agents(state, neighbors, p_adopt)
  return state

# Beispielsimulation
N = 100  # Populationsgröße
p_initial = 0.1  # Wahrscheinlichkeit der anfänglichen Annahme
p_adopt = 0.8  # Wahrscheinlichkeit der Annahme durch sozialen Einfluss
T = 100  # Anzahl der Zeitschritte
k = 5  # Anzahl der zu wählenden Nachbarn (Beispiel)

final_state = simulate(N, p_initial, p_adopt, T, k)

# Analyse der Ergebnisse
adoption_rate = np.mean(final_state)
print(f"Akzeptanzrate: {adoption_rate}")

