import numpy as np
import random
import matplotlib.pyplot as plt

def initialize_agents(N, p_initial):
  """Initialisiert eine Population von Agenten."""
  state = np.zeros(N)
  for i in range(N):
    if random.random() < p_initial:
      state[i] = 1
  return state

def select_neighbors(N, k):
  """Wählt zufällige Nachbarn für jeden Agenten aus."""
  neighbors = np.zeros((N, k), dtype=int)
  for i in range(N):
    neighbors[i] = np.random.choice(N, size=k, replace=False)
  return neighbors

def update_agents(state, neighbors, p_adopt):
  """Aktualisiert den Zustand der Agenten basierend auf sozialer Beeinflussung."""
  new_state = state.copy()
  for i in range(N):
    valid_neighbors = neighbors[i][neighbors[i] >= 0]
    if len(valid_neighbors) > 0:
      majority_adopted = np.mean(state[valid_neighbors]) >= 0.5
      if state[i] == 0 and majority_adopted:
        if random.random() < p_adopt:
          new_state[i] = 1
  return new_state

def simulate(N, p_initial, p_adopt, T, k):
  """Führt die Simulation durch und speichert die Adoptionsrate."""
  adoption_rates = []  # Speichert die Adoptionsrate pro Zeitschritt
  state = initialize_agents(N, p_initial)
  for t in range(T):
    neighbors = select_neighbors(N, k)
    state = update_agents(state, neighbors, p_adopt)
    adoption_rates.append(np.mean(state))
  return adoption_rates

# Beispielsimulation
N = 500
p_initial = 0.02
p_adopt = 0.8
T = 100
k = 5

adoption_rates = simulate(N, p_initial, p_adopt, T, k)

# Visualisierung des Verlaufs
plt.plot(adoption_rates)
plt.xlabel("Zeitschritt")
plt.ylabel("Akzeptanzrate")
plt.title(f"Verbreitung des Angebots (N={N}, p_initial={p_initial}, p_adopt={p_adopt}, k={k})")
plt.show()

