import numpy as np
import random
import matplotlib.pyplot as plt

# Anzahl der Bürger und Behörden
num_citizens = 100
num_agencies = 20

# Initialisierung der eID-Einstellungen
initial_eid_proportion = 0.1
citizen_eid_attitudes = np.random.normal(50, 20, num_citizens)

# Initialisierung der eID-Dienste
initial_eid_services_proportion = 0.1
agency_eid_services = np.random.choice([True, False], size=num_agencies, p=[initial_eid_services_proportion, 1-initial_eid_services_proportion])

# Simulations-Parameter
usage_difficulty_range = (0, 100)
interaction_probability = 0.1

# Speichern der eID-Einstellungen über die Zeit
citizen_eid_attitudes_over_time = []

# Simulationsschleife
for time_step in range(100):
    # Bürger laufen umher und interagieren mit Behörden
    for citizen_id, citizen_attitude in enumerate(citizen_eid_attitudes):
        if random.random() < interaction_probability:
            agency_id = random.randint(0, num_agencies - 1)

            if agency_eid_services[agency_id] and citizen_eid_attitudes[citizen_id] > 0:
                usage_difficulty = random.randint(*usage_difficulty_range)
                citizen_eid_attitudes[citizen_id] += 100 - usage_difficulty if usage_difficulty <= 50 else -usage_difficulty

                # Begrenzen Sie die Einstellung auf 0-100
                citizen_eid_attitudes[citizen_id] = max(0, min(citizen_eid_attitudes[citizen_id], 100))

    # Speichern Sie die durchschnittliche eID-Einstellung für den aktuellen Zeitschritt
    citizen_eid_attitudes_over_time.append(citizen_eid_attitudes.mean())

# Visualisierung der eID-Einstellungen über die Zeit
plt.plot(citizen_eid_attitudes_over_time)
plt.xlabel("Zeitschritt")
plt.ylabel("Durchschnittliche eID-Einstellung")
plt.title("Entwicklung der eID-Einstellungen im Laufe der Zeit")
plt.show()
